#================ ObelixFHD_AEL_MovieWall_Info =============
# AELMovieWallData: Datum | Uhrzeit | Duration | FileSize | FreeDiskSpace
# FreeDiskSpace: FreeDiskSpace

from Components.Converter.Converter import Converter
from Components.Element import cached

from time import time, localtime, strftime
from enigma import iServiceInformation
from Tools.Bytes2Human import bytes2human
from os import statvfs

class ObelixFHD_MovieData(Converter, object):
	def __init__(self, type):
		Converter.__init__(self, type)
		self.type = type

	@cached
	def getText(self):
		
		service = self.source.service
		event = self.source.event
		info = self.source.info
		
		#=========== DateTime/Duration ================
		if info and service:
			#=========== StartTime ================
			StartTimeStr = ""
			StartTime = info.getInfo(service, iServiceInformation.sTimeCreate)
			if StartTime and StartTime > 0:
				StartTimeStr = self.fTimeToStr(localtime(StartTime),'%a. %d.%m.%Y  |  %H:%M')
				
			#=========== Duration ================
			DurationStr = ""
			Duration = info.getLength(service)		
			if Duration and Duration > 0:
				DurationStr = '%d min' % (Duration / 60)
				
			#=========== EndTime ================
			EndTimeStr = ""
			if StartTime and Duration and StartTime > 0 and Duration > 0:
				EndTime = StartTime + Duration
				EndTimeStr = self.fTimeToStr(localtime(EndTime),' - %H:%M')
				
			#=========== DateTimeStr ================
			DateTimeStr = ""
			if StartTimeStr:
				DateTimeStr = StartTimeStr
				if EndTimeStr:
					DateTimeStr = DateTimeStr + EndTimeStr
			
			#=========== FileSize ================
			FileSizeStr = ""
			FileSize = info.getInfoObject(service, iServiceInformation.sFileSize)
			if FileSize is not None:
				FileSizeStr = '%s' % bytes2human(FileSize, 1)
				
			#=========== FreeDiskSpace ================
			FreeDiskSpaceStr = ""
			try:
				path = service.getPath()
				if path:
					stat = statvfs(path)
					free = (stat.f_bavail or stat.f_bfree) * stat.f_bsize
					FreeDiskSpaceStr = str(bytes2human(free, 1))
					if FreeDiskSpaceStr == "0 B":
						FreeDiskSpaceStr = ""
					else:
						FreeDiskSpaceStr = FreeDiskSpaceStr + " Frei"
			except:
				pass

			#=========== ReturnStr ================
			ReturnStr = ""
			
			if self.type == "AELMovieWallData":
				if DateTimeStr:
					ReturnStr = DateTimeStr
				if DurationStr:
					if ReturnStr:
						ReturnStr = ReturnStr + "  |  "
					ReturnStr = ReturnStr + DurationStr
				if FileSizeStr:
					if ReturnStr:
						ReturnStr = ReturnStr + "  |  "
					ReturnStr = ReturnStr + FileSizeStr
				if FreeDiskSpaceStr:
					if ReturnStr:
						ReturnStr = ReturnStr + "  |  "
						ReturnStr = ReturnStr + FreeDiskSpaceStr
						
			if self.type == "FreeDiskSpace":
				ReturnStr = FreeDiskSpaceStr
				
			return ReturnStr
		return ""

	text = property(getText)
	
	#=========== fTimeToStr ================
	def fTimeToStr(self,InputTime,fmt_string):
		weekday_long = ('Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday')
		weekday_short = ('Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun')
		month_long = ('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December')
		month_short = ('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec')
		str_fmt_values = {
			'%B': month_long, 
			'%b': month_short,
			'%A': weekday_long,
			'%a': weekday_short}
		return_str = strftime(fmt_string, InputTime)
		for key in str_fmt_values:
			if fmt_string.find(key) != -1:
				for value in str_fmt_values[key]:
					if key == '%b' and value == 'May':
						r_value = _(value)[:3]
					else:
						r_value = _(value)
					if return_str.find(value) != -1:
						return_str = return_str.replace(value, r_value)
						break
		return return_str
	
# =========================================================
